@@ -12,8 +12,8 @@ function (v1, v2, names = c("v1", "v2"), cap = "", lab = "",
     s1 <- as.vector(apply(mat, 2, sum))
     s2 <- as.vector(apply(mat, 1, sum))
     s3 <- sum(mat)
-    n.v1 <- length(unique(v1))
-    n.v2 <- length(unique(v2))
+    n.v1 <- length(unique(v1[is.na(v1) == FALSE]))
+    n.v2 <- length(unique(v2[is.na(v2) == FALSE]))
     mat <- rbind(col.nam, mat, s1)
     mat <- cbind(c(NA, row.nam, "Total"), mat)
     mat <- cbind(mat, c("Total", s2, s3))
